@@ -7,6 +7,6 @@ class ErrorMiddleware(MiddlewareMixin):
 
     def process_exception(self, request, exception):
         if isinstance(exception, ValidationError):
-            return JsonResponse({'errors': exception.errors()})
+            return JsonResponse({'errors': exception.errors()}, status=500)
         else:
             raise exception
